@@ -1,4 +1,4 @@
 from .task import TaskBase
 from .funcaptcha import FuncaptchaTask
-from .hcaptcha import HCaptchaTask
+from .hcaptcha import HCaptchaTask, HCaptchaEnterpriseTask
 from .recaptcha import ReCaptchaV3Task
\ No newline at end of file
